package com.ruoyi.tcZz.service;

import java.util.List;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcWljgtj;

/**
 * 网络监测统计Service接口
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
public interface ITcWljgtjService 
{
    /**
     * 查询网络监测统计
     * 
     * @param id 网络监测统计主键
     * @return 网络监测统计
     */
    public TcWljgtj selectTcWljgtjById(Long id);

    /**
     * 查询网络监测统计列表
     * 
     * @param tcWljgtj 网络监测统计
     * @return 网络监测统计集合
     */
    public List<TcWljgtj> selectTcWljgtjList(TcWljgtj tcWljgtj);

    /**
     * 新增网络监测统计
     * 
     * @param tcWljgtj 网络监测统计
     * @return 结果
     */
    public int insertTcWljgtj(TcWljgtj tcWljgtj);

    /**
     * 修改网络监测统计
     * 
     * @param tcWljgtj 网络监测统计
     * @return 结果
     */
    public int updateTcWljgtj(TcWljgtj tcWljgtj);

    /**
     * 批量删除网络监测统计
     * 
     * @param ids 需要删除的网络监测统计主键集合
     * @return 结果
     */
    public int deleteTcWljgtjByIds(Long[] ids);

    /**
     * 删除网络监测统计信息
     * 
     * @param id 网络监测统计主键
     * @return 结果
     */
    public int deleteTcWljgtjById(Long id);


    /**
     * 导入网络监测统计信息
     *
     * @return 结果
     */
    public String importUser(List<TcWljgtj> tcWljgtjList);

    /**
     * 批量启用禁用
     *
     *
     */
    public void updateByisStatus(Integer isStatus,List<String> ids);
}
