package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcAqg;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.service.ITcWljgtjService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 网络监测统计Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "网络监测统计")
@RequestMapping("/tcZz/networkSecurity/wljgtj")
public class TcWljgtjController extends BaseController {
    @Autowired
    private ITcWljgtjService tcWljgtjService;

    /**
     * 查询网络监测统计列表
     */
    @ApiOperation(value = "查询网络监测统计列表",response =TcWljgtj.class )
    @GetMapping("/list")
    public TableDataInfo list(TcWljgtj tcWljgtj) {
        startPage();
        List<TcWljgtj> list = tcWljgtjService.selectTcWljgtjList(tcWljgtj);
        return getDataTable(list);
    }

    /**
     * 导出网络监测统计列表
     */
    @ApiOperation("导出网络监测统计列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcWljgtj tcWljgtj) {
        List<TcWljgtj> list = tcWljgtjService.selectTcWljgtjList(tcWljgtj);
        ExcelUtil<TcWljgtj> util = new ExcelUtil<TcWljgtj>(TcWljgtj.class);
        util.exportExcel(response, list, "网络监测统计数据");
    }

    /**
     * 获取网络监测统计详细信息
     */
    @ApiOperation("获取网络监测统计详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcWljgtjService.selectTcWljgtjById(id));
    }

    /**
     * 新增网络监测统计
     */
    @ApiOperation("新增网络监测统计")
    @PostMapping
    public AjaxResult add(@RequestBody TcWljgtj tcWljgtj) {
        return toAjax(tcWljgtjService.insertTcWljgtj(tcWljgtj));
    }

    /**
     * 修改网络监测统计
     */
    @ApiOperation("修改网络监测统计")
    @PutMapping
    public AjaxResult edit(@RequestBody TcWljgtj tcWljgtj) {
        return toAjax(tcWljgtjService.updateTcWljgtj(tcWljgtj));
    }

    /**
     * 删除网络监测统计
     */
    @ApiOperation("删除网络监测统计")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcWljgtjService.deleteTcWljgtjByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcWljgtj> util = new ExcelUtil<TcWljgtj>(TcWljgtj.class);
        List<TcWljgtj> tcWljgtjList = util.importExcel(file.getInputStream());
        tcWljgtjService.importUser(tcWljgtjList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcWljgtjService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcWljgtj> util = new ExcelUtil<TcWljgtj>(TcWljgtj.class);
        util.importTemplateExcel(response, " 网络监测统计");
    }
}
